@@ -1,17 +1,17 @@
-# Copyright (C) 2022 Brodie Gaslam
-# 
-# This file is part of "unitizer"
-# 
+# Copyright (C) Brodie Gaslam
+#
+# This file is part of "unitizer - Interactive R Unit Tests"
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
 
 # Alter Older unitizer Versions So They Pass Validation in Latest Version
@@ -197,13 +197,16 @@ upgrade_internal <- function(object) {
     object <- addSlot(object, "bookmark", NULL)
     object <- removeSlots(object, "jump.to.test")
   }
-  # - 1.4.15 --------------------------------------------------------------------
+  # - 1.4.x --------------------------------------------------------------------
 
   if(ver < "1.4.15") {
     object <- addSlot(object, "upgraded.from", "")
     object <- addSlot(object, "best.name", "")
     object <- addSlot(object, "show.progress", PROGRESS.MAX)
   }
+  if(ver < "1.4.17.9006") {
+    object <- addSlot(object, "transcript", FALSE)
+  }
   # - Keep at End---------------------------------------------------------------
 
   # Always make sure that any added upgrades require a version bump as we always
